summaryrefslogtreecommitdiff
path: root/bucket-cache_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'bucket-cache_test.go')
-rw-r--r--bucket-cache_test.go24
1 files changed, 11 insertions, 13 deletions
diff --git a/bucket-cache_test.go b/bucket-cache_test.go
index 507b408..e095a5c 100644
--- a/bucket-cache_test.go
+++ b/bucket-cache_test.go
@@ -1,6 +1,6 @@
/*
* Copyright
- * 2015, 2016, 2017 Minio, Inc.
+ * 2015, 2016, 2017 MinIO, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -27,8 +27,8 @@ import (
"reflect"
"testing"
- "github.com/minio/minio-go/pkg/credentials"
- "github.com/minio/minio-go/pkg/s3signer"
+ "github.com/minio/minio-go/v6/pkg/credentials"
+ "github.com/minio/minio-go/v6/pkg/s3signer"
)
// Test validates `newBucketLocationCache`.
@@ -67,19 +67,18 @@ func TestBucketLocationCacheOps(t *testing.T) {
func TestGetBucketLocationRequest(t *testing.T) {
// Generates expected http request for getBucketLocation.
// Used for asserting with the actual request generated.
- createExpectedRequest := func(c *Client, bucketName string, req *http.Request) (*http.Request, error) {
+ createExpectedRequest := func(c *Client, bucketName string) (*http.Request, error) {
// Set location query.
urlValues := make(url.Values)
urlValues.Set("location", "")
// Set get bucket location always as path style.
- targetURL := c.endpointURL
+ targetURL := *c.endpointURL
targetURL.Path = path.Join(bucketName, "") + "/"
targetURL.RawQuery = urlValues.Encode()
// Get a new HTTP request for the method.
- var err error
- req, err = http.NewRequest("GET", targetURL.String(), nil)
+ req, err := http.NewRequest("GET", targetURL.String(), nil)
if err != nil {
return nil, err
}
@@ -156,10 +155,10 @@ func TestGetBucketLocationRequest(t *testing.T) {
{"storage.googleapis.com", "my-access-key", "my-secret-key", false},
{"storage.googleapis.com", "", "my-secret-key", false},
- // endpoint custom domain running Minio server.
- {"play.minio.io", "", "", false},
- {"play.minio.io", "my-access-key", "my-secret-key", false},
- {"play.minio.io", "my-acess-key", "", false},
+ // endpoint custom domain running MinIO server.
+ {"play.min.io", "", "", false},
+ {"play.min.io", "my-access-key", "my-secret-key", false},
+ {"play.min.io", "my-acess-key", "", false},
}
testCases := []struct {
bucketName string
@@ -251,8 +250,7 @@ func TestGetBucketLocationRequest(t *testing.T) {
// Test passes as expected, but the output values are verified for correctness here.
if err == nil && testCase.shouldPass {
- expectedReq := &http.Request{}
- expectedReq, err = createExpectedRequest(client, testCase.bucketName, expectedReq)
+ expectedReq, err := createExpectedRequest(client, testCase.bucketName)
if err != nil {
t.Fatalf("Test %d: Expected request Creation failed", i+1)
}